==> datadog-cdk-constructs-v2-1.1.0.tar.gz: package/lib/common/constants.d.ts <==
export declare const LAYER_PREFIX = "DatadogLayer";
export declare const EXTENSION_LAYER_PREFIX = "DatadogExtension";
export declare const DD_ACCOUNT_ID = "464622532012";
export declare const DD_GOV_ACCOUNT_ID = "002406178527";
export declare const DD_HANDLER_ENV_VAR = "DD_LAMBDA_HANDLER";
export declare const PYTHON_HANDLER = "datadog_lambda.handler.handler";
export declare const JS_HANDLER_WITH_LAYERS = "/opt/nodejs/node_modules/datadog-lambda-js/handler.handler";
export declare const JS_HANDLER = "node_modules/datadog-lambda-js/dist/handler.handler";
export declare const SUBSCRIPTION_FILTER_PREFIX = "DatadogSubscriptionFilter";
/**
 * @stability stable
 */
export declare enum RuntimeType {
    /**
     * @stability stable
     */
    NODE = 0,
    /**
     * @stability stable
     */
    PYTHON = 1,
    /**
     * @stability stable
     */
    UNSUPPORTED = 2
}
export declare const DefaultDatadogProps: {
    addLayers: boolean;
    enableDatadogTracing: boolean;
    enableMergeXrayTraces: boolean;
    injectLogContext: boolean;
    enableDatadogLogs: boolean;
    architecture: string;
    captureLambdaPayload: boolean;
};
/**
 * @stability stable
 */
export declare enum TagKeys {
    /**
     * @stability stable
     */
    CDK = "dd_cdk_construct",
    /**
     * @stability stable
     */
    ENV = "env",
    /**
     * @stability stable
     */
    SERVICE = "service",
    /**
     * @stability stable
     */
    VERSION = "version"
}
export declare const runtimeLookup: {
    [key: string]: RuntimeType;
};
export declare const runtimeToLayerName: {
    [key: string]: string;
};
export declare const govCloudRegions: ReadonlyArray<string>;

==> datadog-cdk-constructs-v2-1.5.0.tar.gz: package/lib/common/constants.d.ts <==
export declare const LAYER_PREFIX = "DatadogLayer";
export declare const EXTENSION_LAYER_PREFIX = "DatadogExtension";
export declare const DD_ACCOUNT_ID = "464622532012";
export declare const DD_GOV_ACCOUNT_ID = "002406178527";
export declare const DD_HANDLER_ENV_VAR = "DD_LAMBDA_HANDLER";
export declare const AWS_JAVA_WRAPPER_ENV_VAR = "AWS_LAMBDA_EXEC_WRAPPER";
export declare const AWS_JAVA_WRAPPER_ENV_VAR_VALUE = "/opt/datadog_wrapper";
export declare const PYTHON_HANDLER = "datadog_lambda.handler.handler";
export declare const JS_HANDLER_WITH_LAYERS = "/opt/nodejs/node_modules/datadog-lambda-js/handler.handler";
export declare const JS_HANDLER = "node_modules/datadog-lambda-js/dist/handler.handler";
export declare const SUBSCRIPTION_FILTER_PREFIX = "DatadogSubscriptionFilter";
export declare enum RuntimeType {
    NODE = 0,
    PYTHON = 1,
    JAVA = 2,
    UNSUPPORTED = 3
}
export declare const DefaultDatadogProps: {
    addLayers: boolean;
    enableDatadogTracing: boolean;
    enableMergeXrayTraces: boolean;
    injectLogContext: boolean;
    enableDatadogLogs: boolean;
    architecture: string;
    captureLambdaPayload: boolean;
    sourceCodeIntegration: boolean;
};
export declare enum TagKeys {
    CDK = "dd_cdk_construct",
    ENV = "env",
    SERVICE = "service",
    VERSION = "version"
}
export declare const runtimeLookup: {
    [key: string]: RuntimeType;
};
export declare const runtimeToLayerName: {
    [key: string]: string;
};
export declare const govCloudRegions: ReadonlyArray<string>;
